@@ -7,7 +7,7 @@ use sphinx::source::{ModuleSource, SourceText};
 use sphinx::parser::expr::Expr;
 use sphinx::parser::stmt::{Stmt, StmtMeta};
 use sphinx::codegen::{Program, CompiledProgram};
-use sphinx::runtime::{Module, VirtualMachine, GC};
+use sphinx::runtime::{Module, VirtualMachine, Gc};
 use sphinx::runtime::module::GlobalEnv;
 use sphinx::runtime::strings::StringInterner;
 use sphinx::debug::symbol::resolver::BufferedResolver;
@@ -65,7 +65,7 @@ fn main() {
         source = ModuleSource::File(PathBuf::from(s));
         name = s;
     } else {
-        let repl_env = GC::new(stdlib::prelude_env());
+        let repl_env = stdlib::create_prelude();
         Repl::new(version.to_string(), repl_env).run();
         
         return;
@@ -81,7 +81,7 @@ fn main() {
         if let Some(build) = build_program(&source) {
             let program = Program::load(build.program);
             
-            let repl_env = GC::new(stdlib::prelude_env());
+            let repl_env = stdlib::create_prelude();
             let main_module = Module::with_env(Some(source), program.data, repl_env);
             
             let vm = VirtualMachine::new(main_module, &program.main);
@@ -97,7 +97,7 @@ fn main() {
     else if let Some(build) = build_program(&source) {
         let program = Program::load(build.program);
         
-        let main_env = GC::new(stdlib::prelude_env());
+        let main_env = stdlib::create_prelude();
         let main_module = Module::with_env(Some(source), program.data, main_env);
         
         let vm = VirtualMachine::new(main_module, &program.main);
@@ -172,7 +172,7 @@ const PROMT_CONTINUE: &str = "... ";
 
 struct Repl {
     version: String,
-    repl_env: GC<GlobalEnv>,
+    repl_env: Gc<GlobalEnv>,
 }
 
 enum ReadLine {
@@ -183,7 +183,7 @@ enum ReadLine {
 }
 
 impl Repl {
-    pub fn new(version: String, repl_env: GC<GlobalEnv>) -> Self {
+    pub fn new(version: String, repl_env: Gc<GlobalEnv>) -> Self {
         Self {
             version, repl_env,
         }
