@@ -1,10 +1,10 @@
-use std::fmt;
+use core::fmt;
 use std::error::Error;
 
 use crate::utils;
 use crate::runtime::Variant;
 use crate::runtime::function::Signature;
-use crate::runtime::gc::{GC, GCTrace};
+use crate::runtime::gc::GcTrace;
 use crate::runtime::types::{Type, MethodTag};
 use crate::runtime::strings::StringSymbol;
 use crate::debug::traceback::{TraceSite, Traceback};
@@ -42,7 +42,7 @@ impl From<ErrorKind> for Box<RuntimeError> {
     }
 }
 
-unsafe impl GCTrace for ErrorKind {
+unsafe impl GcTrace for ErrorKind {
     fn trace(&self) {
         match self {
             Self::UnhashableValue(value) => value.trace(),
@@ -52,8 +52,8 @@ unsafe impl GCTrace for ErrorKind {
     
     fn size_hint(&self) -> usize {
         match self {
-            Self::MissingArguments { .. } => std::mem::size_of::<Signature>(),
-            Self::TooManyArguments { .. } => std::mem::size_of::<Signature>(),
+            Self::MissingArguments { .. } => core::mem::size_of::<Signature>(),
+            Self::TooManyArguments { .. } => core::mem::size_of::<Signature>(),
             _ => 0,
         }
     }
@@ -68,7 +68,7 @@ pub struct RuntimeError {
     cause: Option<Box<RuntimeError>>,
 }
 
-unsafe impl GCTrace for RuntimeError {
+unsafe impl GcTrace for RuntimeError {
     fn trace(&self) {
         self.kind.trace();
         for site in self.traceback.iter() {
@@ -130,6 +130,8 @@ impl fmt::Display for RuntimeError {
                     MethodTag::AsInt => format!("can't interpret '{}' as int", receiver),
                     MethodTag::AsFloat => format!("can't interpret '{}' as float", receiver),
                     MethodTag::Invoke => format!("type '{}' is not callable", receiver),
+                    MethodTag::Next => format!("type '{}' is not an iterator", receiver),
+                    MethodTag::Iter => format!("type '{}' is not iterable", receiver),
                     _ => format!("type '{}' does not support '{}'", receiver, method),
                 }
             }
