@@ -1,7 +1,6 @@
-use std::fmt;
+use core::fmt;
 use crate::parser::lvalue::DeclType;
 use crate::runtime::Variant;
-use crate::runtime::gc::{GC, GCTrace};
 use crate::runtime::strings::{StringSymbol, STRING_TABLE};
 use crate::runtime::errors::{ExecResult, ErrorKind};
 
