@@ -1,65 +1,24 @@
 /// Partial clone of rust-gc's mark and sweep implementation
 
-use std::fmt;
-use std::mem;
-use std::ptr::{self, NonNull};
-use std::cell::{Cell, RefCell};
+use core::fmt;
+use core::ptr::NonNull;
+use core::cell::{Cell, RefCell};
 use log;
 
+mod data;
 mod handle;
-pub use handle::GC;
 
+pub use data::GcTrace;
+pub use handle::Gc;
 
-/// TODO store GCBoxes in linear chunks instead of individual linked nodes
-struct GCBox<T> where T: GCTrace + ?Sized + 'static {
-    next: Option<NonNull<GCBox<dyn GCTrace>>>,
-    marked: bool,
-    data: T,
-}
-
-impl<T> GCBox<T> where T: GCTrace + ?Sized {
-    fn value(&self) -> &T { &self.data }
-    
-    #[inline]
-    fn size(&self) -> usize {
-        mem::size_of_val(self) + self.value().size_hint()
-    }
-    
-    fn ptr_eq(&self, other: &GCBox<T>) -> bool {
-        // in case T is a trait object, work around for <https://github.com/rust-lang/rust/issues/46139>
-        ptr::eq(&self.marked, &other.marked)
-    }
-    
-    fn mark_trace(&mut self) {
-        if !self.marked {
-            self.marked = true;
-            self.data.trace();
-        }
-    }
-}
-
-
-/// Unsafe because if the GCTrace::trace() implementation fails to mark any GC handles that it can reach, 
-/// the GC will not be able to mark them and will free memory that is still in use.
-/// SAFETY: Must not impl Drop
-pub unsafe trait GCTrace {
-    
-    /// SAFETY: Must call `GC::mark_trace()` on every reachable GC handle
-    fn trace(&self);
-    
-    /// If the GCTrace owns any allocations, this should return the extra allocated size.
-    /// If the allocation can change size, like a Vec<T>, then don't include it in the 
-    /// size hint, or return a const estimate of the average size.
-    #[inline]
-    fn size_hint(&self) -> usize { 0 }
-}
+use data::{GcBox, GcBoxHeader};
 
 
 thread_local! {
-    static GC_STATE: RefCell<GCState> = RefCell::new(GCState::default());
+    static GC_STATE: RefCell<GcState> = RefCell::new(GcState::default());
 }
 
-pub fn gc_collect(root: &impl GCTrace) {
+pub fn gc_collect(root: &impl GcTrace) {
     GC_STATE.with(|gc| {
         let mut gc = gc.borrow_mut();
         if gc.should_collect() {
@@ -68,33 +27,33 @@ pub fn gc_collect(root: &impl GCTrace) {
     })
 }
 
-pub fn gc_force(root: &impl GCTrace) {
+pub fn gc_force(root: &impl GcTrace) {
     GC_STATE.with(|gc| {
         let mut gc = gc.borrow_mut();
         gc.collect_garbage(root)
     })
 }
 
-struct GCState {
-    stats: GCStats,
-    config: GCConfig,
+struct GcState {
+    stats: GcStats,
+    config: GcConfig,
     threshold: usize,
-    boxes_start: Option<NonNull<GCBox<dyn GCTrace>>>,
+    boxes_start: Option<NonNull<GcBoxHeader>>,
 }
 
 #[derive(Debug)]
-struct GCStats {
+struct GcStats {
     allocated: usize,
     box_count: usize,
     cycle_count: usize,
 }
 
-struct GCConfig {
+struct GcConfig {
     threshold: u16,
     pause_factor: u16,  // percent memory use relative to last cycle before starting a new cycle
 }
 
-impl Default for GCConfig {
+impl Default for GcConfig {
     fn default() -> Self {
         Self {
             threshold: 512, // Small because of stop-the-world. If we go incremental increase this to 8 kiB
@@ -103,21 +62,21 @@ impl Default for GCConfig {
     }
 }
 
-impl Default for GCState {
+impl Default for GcState {
     fn default() -> Self {
-        GCState::new(GCConfig::default())
+        GcState::new(GcConfig::default())
     }
 }
 
-impl GCState {
-    fn new(config: GCConfig) -> Self {
+impl GcState {
+    fn new(config: GcConfig) -> Self {
         let threshold = config.threshold as usize;
         
         Self {
             config,
             threshold,
             
-            stats: GCStats {
+            stats: GcStats {
                 allocated: 0,
                 box_count: 0,
                 cycle_count: 0,
@@ -132,48 +91,30 @@ impl GCState {
         self.stats.allocated > self.threshold
     }
     
-    fn allocate<T: GCTrace>(&mut self, data: T) -> NonNull<GCBox<T>> {
-        
-        let gcbox = Box::new(GCBox {
-            next: self.boxes_start.take(),
-            marked: false,
-            data,
-        });
-
-        let size = gcbox.size();
-        let ptr = Box::into_raw(gcbox);
-        log::debug!("{:#X} allocate {} bytes", ptr as usize, size);
-        
-        let ptr = unsafe {
-            NonNull::new_unchecked(ptr)
-        };
-        
-        self.boxes_start = Some(ptr);
-        self.stats.allocated += size;
-        self.stats.box_count += 1;
-        
-        ptr
+    fn insert(&mut self, mut gcbox: NonNull<GcBoxHeader>) {
+        unsafe {
+            let size = gcbox.as_ref().size();
+            log::debug!("{:#X} allocate {} bytes", gcbox.as_ptr() as *const () as usize, size);
+            
+            gcbox.as_mut().set_next(self.boxes_start.take());
+            self.boxes_start = Some(gcbox);
+            self.stats.allocated += size;
+            self.stats.box_count += 1;
+        }
     }
     
-    /// frees the GCBox, yielding it's next pointer
-    fn free(&mut self, gcbox: NonNull<GCBox<dyn GCTrace>>) -> Option<NonNull<GCBox<dyn GCTrace>>> {
-        let ptr = gcbox.as_ptr();
-        
-        // SAFETY: This is safe as long as we only ever free() GCBoxes that were created by allocate()
-        let gcbox = unsafe { Box::from_raw(ptr) };
-        
-        let size = gcbox.size();
+    /// frees the GcBox, yielding it's next pointer
+    fn free(&mut self, gcbox: NonNull<GcBoxHeader>) -> Option<NonNull<GcBoxHeader>> {
+        let size = unsafe { gcbox.as_ref().size() };
         self.stats.allocated -= size;
         self.stats.box_count -= 1;
-        log::debug!("{:#X} free {} bytes", ptr as *const () as usize, size);
+        log::debug!("{:#X} free {} bytes", gcbox.as_ptr() as *const () as usize, size);
         
-        gcbox.next
-        
-        // gcbox should get dropped here
+        unsafe { GcBoxHeader::free(gcbox) }
     }
     
-    fn collect_garbage(&mut self, root: &impl GCTrace) {
-        log::debug!("GC cycle begin ---");
+    fn collect_garbage(&mut self, root: &impl GcTrace) {
+        log::debug!("Gc cycle begin ---");
         
         let allocated = self.stats.allocated;
         let box_count = self.stats.box_count;
@@ -194,29 +135,27 @@ impl GCState {
         self.threshold = (self.stats.allocated * self.config.pause_factor as usize) / 100;
         log::debug!("Next collection at {} bytes", self.threshold);
         
-        log::debug!("GC cycle end ---");
+        log::debug!("Gc cycle end ---");
     }
     
     unsafe fn sweep(&mut self) {
         let _guard = DropGuard::new();
         
-        //boxes_start: Option<NonNull<GCBox<dyn GCTrace>>>,
+        //boxes_start: Option<NonNull<GcBox<dyn GcTrace>>>,
         let mut prev_box = None;
         let mut next_box = self.boxes_start;
-        while let Some(gcbox) = next_box {
-            let box_ptr = gcbox.as_ptr();
-            
-            if (*box_ptr).marked {
-                (*box_ptr).marked = false;
+        while let Some(mut gcbox) = next_box {
+            if gcbox.as_ref().is_marked() {
+                gcbox.as_mut().set_marked(false);
                 
-                next_box = (*box_ptr).next;
+                next_box = gcbox.as_ref().next();
                 prev_box.replace(gcbox);
                 
             } else {
                 
                 next_box = self.free(gcbox);
-                if let Some(prev_box) = prev_box {
-                    (*prev_box.as_ptr()).next = next_box;
+                if let Some(mut prev_box) = prev_box {
+                    prev_box.as_mut().set_next(next_box);
                 } else {
                     self.boxes_start = next_box;
                 }
@@ -226,7 +165,7 @@ impl GCState {
     }
 }
 
-impl Drop for GCState {
+impl Drop for GcState {
     fn drop(&mut self) {
         // unimplemented!()
     }
@@ -256,7 +195,7 @@ fn deref_safe() -> bool {
 }
 
 
-impl fmt::Display for GCStats {
+impl fmt::Display for GcStats {
     fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
             fmt, "Cycle {}: estimated usage {}u ({} allocations)", 
