@@ -6,16 +6,15 @@
 ///! Importing a Sphinx module simply means executing a Sphinx sub-program and binding the
 ///! resulting module to a name.
 
-use std::fmt;
+use core::fmt;
+use core::cell::{RefCell, Ref, RefMut};
+use core::hash::{Hash, Hasher, BuildHasher};
 use std::path::PathBuf;
-use std::cell::{RefCell, Ref, RefMut};
-use std::hash::{Hash, Hasher, BuildHasher};
 use once_cell::sync::Lazy;
 use crate::source::ModuleSource;
 use crate::language::FloatType;
 use crate::runtime::{Variant, HashMap, DefaultBuildHasher};
-use crate::runtime::gc::{GC, GCTrace};
-use crate::runtime::function::Function;
+use crate::runtime::gc::{Gc, GcTrace};
 use crate::runtime::strings::StringSymbol;
 use crate::runtime::errors::{ExecResult, RuntimeError, ErrorKind};
 
@@ -95,6 +94,7 @@ impl Namespace {
 }
 
 
+/// Mutable container for storing a Namespace in a Gc.
 #[derive(Debug, Default, Clone)]
 pub struct GlobalEnv {
     namespace: RefCell<Namespace>,
@@ -107,12 +107,8 @@ impl From<Namespace> for GlobalEnv {
 }
 
 impl GlobalEnv {
-    pub fn new() -> Self {
-        Self::default()
-    }
-    
-    pub fn allocate() -> GC<Self> {
-        GC::new(Self::default())
+    pub fn new() -> Gc<Self> {
+        Gc::new(Self::default())
     }
     
     pub fn borrow(&self) -> Ref<Namespace> {
@@ -124,7 +120,7 @@ impl GlobalEnv {
     }
 }
 
-unsafe impl GCTrace for GlobalEnv {
+unsafe impl GcTrace for GlobalEnv {
     fn trace(&self) {
         for value in self.namespace.borrow().values() {
             value.trace();
@@ -139,22 +135,22 @@ pub struct Module {
     display: String,
     source: Option<ModuleSource>,
     data: ProgramData,
-    globals: GC<GlobalEnv>,
+    globals: Gc<GlobalEnv>,
 }
 
-unsafe impl GCTrace for Module {
+unsafe impl GcTrace for Module {
     fn trace(&self) {
         self.globals.mark_trace()
     }
 }
 
 impl Module {
-    pub fn allocate(source: Option<ModuleSource>, data: ProgramData) -> GC<Self> {
-        let globals = GlobalEnv::allocate();
+    pub fn allocate(source: Option<ModuleSource>, data: ProgramData) -> Gc<Self> {
+        let globals = GlobalEnv::new();
         Self::with_env(source, data, globals)
     }
     
-    pub fn with_env(source: Option<ModuleSource>, data: ProgramData, globals: GC<GlobalEnv>) -> GC<Self> {
+    pub fn with_env(source: Option<ModuleSource>, data: ProgramData, globals: Gc<GlobalEnv>) -> Gc<Self> {
         let ident = 
             if let Some(source) = source.as_ref() { ModuleIdent::from(source) }
             else { ModuleIdent::from(globals) };
@@ -169,7 +165,7 @@ impl Module {
             globals,
         };
         
-        GC::new(module)
+        Gc::new(module)
     }
     
     pub fn ident(&self) -> &ModuleIdent { &self.ident }
@@ -180,7 +176,7 @@ impl Module {
     pub fn data(&self) -> &ProgramData { &self.data }
     
     #[inline(always)]
-    pub fn globals(&self) -> &GlobalEnv { &self.globals }
+    pub fn globals(&self) -> Gc<GlobalEnv> { self.globals }
     
     #[inline]
     pub fn get_const(&self, cid: ConstID) -> Variant {
@@ -211,7 +207,7 @@ impl fmt::Display for Module {
 pub enum ModuleIdent {
     SourcePath(PathBuf), // canonicalized path to the source file
     SourceHash(u64),  // hash of source text
-    RefHash(u64),  // GC address of globals, for Native Modules
+    RefHash(u64),  // Gc address of globals, for Native Modules
 }
 
 
@@ -235,10 +231,10 @@ impl From<&ModuleSource> for ModuleIdent {
     }
 }
 
-impl From<GC<GlobalEnv>> for ModuleIdent {
-    fn from(env: GC<GlobalEnv>) -> Self {
+impl From<Gc<GlobalEnv>> for ModuleIdent {
+    fn from(env: Gc<GlobalEnv>) -> Self {
         let mut state = MODULE_IDENT_HASH.build_hasher();
-        <GC<GlobalEnv> as Hash>::hash(&env, &mut state);
+        <Gc<GlobalEnv> as Hash>::hash(&env, &mut state);
         let hash = state.finish();
         Self::RefHash(hash)
     }
@@ -249,9 +245,9 @@ impl fmt::Display for ModuleIdent {
         match self {
             Self::SourcePath(path) => {
                 let prefix = std::env::current_dir().ok()
-                    .map(|pwd| pwd.canonicalize().ok()).flatten();
+                    .and_then(|pwd| pwd.canonicalize().ok());
                 
-                let path = prefix.map(|prefix| path.strip_prefix(prefix).ok()).flatten()
+                let path = prefix.and_then(|prefix| path.strip_prefix(prefix).ok())
                     .unwrap_or(path);
                 
                 write!(fmt, "\"{}\"", path.display())
