@@ -1,8 +1,8 @@
-use std::fmt;
-use std::cmp;
-use std::ops::Deref;
-use std::hash::{Hash, Hasher};
-use crate::runtime::gc::{GC, GCTrace};
+use core::fmt;
+use core::cmp;
+use core::ops::Deref;
+use core::hash::{Hash, Hasher};
+use crate::runtime::gc::{Gc, GcTrace};
 use crate::runtime::errors::{ExecResult, ErrorKind};
 
 pub mod intern;
@@ -10,18 +10,29 @@ pub mod inline;
 
 pub use intern::{StringSymbol, StringInterner, STRING_TABLE};
 
-use inline::InlineStr;
 use intern::StringTable;
 
 
 #[derive(Debug, Clone, Copy)]
 pub enum StringValue {
     Intern(StringSymbol),
-    Inline(InlineStr<14>),
-    GC(GC<Box<str>>),
+    Inline(InlineStr),
+    Gc(GCStr),
 }
 
-unsafe impl GCTrace for Box<str> {
+pub type InlineStr = inline::InlineStr<22>;
+
+#[derive(Debug, Clone, Copy)]
+pub struct GCStr(Gc<str>);
+
+impl Deref for GCStr {
+    type Target = Gc<str>;
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+
+unsafe impl GcTrace for str {
     fn trace(&self) { }
     
     fn size_hint(&self) -> usize {
@@ -43,7 +54,7 @@ impl From<&str> for StringValue {
             return Self::Intern(StringSymbol::intern(string))
         }
         
-        Self::GC(GC::new(string.to_string().into_boxed_str()))
+        Self::Gc(GCStr(Gc::from_box(string.to_string().into_boxed_str())))
     }
 }
 
@@ -53,9 +64,21 @@ impl From<StringSymbol> for StringValue {
     }
 }
 
+impl From<InlineStr> for StringValue {
+    fn from(inline: InlineStr) -> Self {
+        StringValue::Inline(inline)
+    }
+}
+
+impl From<GCStr> for StringValue {
+    fn from(gc_str: GCStr) -> Self {
+        StringValue::Gc(gc_str)
+    }
+}
+
 impl StringValue {
     pub fn trace(&self) {
-        if let Self::GC(gc_str) = self {
+        if let Self::Gc(gc_str) = self {
             gc_str.mark_trace()
         }
     }
@@ -64,7 +87,7 @@ impl StringValue {
         match self {
             Self::Intern(symbol) => symbol.write(buf),
             Self::Inline(inline) => buf.write_str(&*inline),
-            Self::GC(gc_str) => buf.write_str(&**gc_str),
+            Self::Gc(gc_str) => buf.write_str(&**gc_str),
         }
     }
     
@@ -73,7 +96,7 @@ impl StringValue {
         match self {
             Self::Intern(symbol) => *symbol,
             Self::Inline(inline) => StringSymbol::intern(&*inline),
-            Self::GC(gc_str) => StringSymbol::intern(&**gc_str),
+            Self::Gc(gc_str) => StringSymbol::intern(&**gc_str),
         }
     }
     
@@ -91,14 +114,14 @@ impl StringValue {
         match self {
             Self::Intern(symbol) => string_table.resolve(symbol),
             Self::Inline(inline) => &*inline,
-            Self::GC(gc_str) => &**gc_str,
+            Self::Gc(gc_str) => &**gc_str,
         }
     }
     
     fn try_str(&self) -> Option<&str> {
         match self {
             Self::Inline(inline) => Some(&*inline),
-            Self::GC(gc_str) => Some(&**gc_str),
+            Self::Gc(gc_str) => Some(&**gc_str),
             _ => None,
         }
     }
@@ -117,7 +140,7 @@ impl StringValue {
 }
 
 // It's important for strings to hash consistently regardless of representation
-// This means that a string "foo" should hash the same whether it is Intern, Inline, or GC
+// This means that a string "foo" should hash the same whether it is Intern, Inline, or Gc
 // Unfortunately Rust's hash API makes it VERY hard to have precise control of the hash output
 // So we either have to lookup and hash the underlying string data each time (which would kill the 
 // performance benefits of string interning) or double-hash.
@@ -130,15 +153,15 @@ impl StringValue {
 impl Hash for StringValue {
     fn hash<H: Hasher>(&self, state: &mut H) {
         STRING_TABLE.with(|string_table| match self {
-            Self::Intern(symbol) => {
-                string_table.borrow().lookup_hash(symbol).hash(state);
-            }
-            Self::Inline(inline) => {
-                string_table.borrow().hash_str(&*inline).hash(state);
-            }
-            Self::GC(gc_str) => {
-                string_table.borrow().hash_str(&**gc_str).hash(state);
-            }
+            Self::Intern(symbol) =>
+                string_table.borrow().lookup_hash(symbol).hash(state),
+            
+            Self::Inline(inline) =>
+                string_table.borrow().hash_str(&*inline).hash(state),
+            
+            Self::Gc(gc_str) => 
+                string_table.borrow().hash_str(&**gc_str).hash(state),
+            
         })
     }
 }
