@@ -1,13 +1,12 @@
-use std::fmt;
-use std::cell::Cell;
-use std::hash::{Hash, Hasher};
-use std::cmp::{PartialEq, Eq};
+use core::fmt;
+use core::hash::{Hash, Hasher};
+use core::cmp::{PartialEq, Eq};
 use static_assertions::assert_eq_size;
 use crate::language::{IntType, FloatType};
-use crate::runtime::types::{Type, Tuple};
-use crate::runtime::function::{Function, NativeFunction, Call};
-use crate::runtime::strings::{StringValue, StringSymbol};
-use crate::runtime::gc::{GC, GCTrace};
+use crate::runtime::types::{Tuple, UserData};
+use crate::runtime::function::{Function, NativeFunction};
+use crate::runtime::strings::{StringValue, StringSymbol, InlineStr, GCStr};
+use crate::runtime::gc::{Gc, GcTrace};
 use crate::runtime::errors::{ExecResult, RuntimeError, ErrorKind};
 
 #[cfg(target_arch = "x86_64")]
@@ -22,16 +21,28 @@ pub enum Variant {
     
     Integer(IntType),
     Float(FloatType),
-    String(StringValue),
     
-    Tuple(Tuple), // TODO: stop using Box when DST support is stabilized
-    Function(GC<Function>),
-    NativeFunction(GC<NativeFunction>),
+    // separate different string types here to keep size down
+    InternStr(StringSymbol),
+    InlineStr(InlineStr),
+    GCStr(GCStr),
+    
+    Tuple(Tuple),
+    Function(Gc<Function>),
+    NativeFunction(Gc<NativeFunction>),
+    
+    UserData(Gc<dyn UserData>),
 }
 
 impl Variant {
-    pub fn as_gc(&self) -> Option<GC<dyn GCTrace>> {
-        GC::<dyn GCTrace>::try_from(self).ok()
+    
+    pub fn as_strval(&self) -> Option<StringValue> {
+        match self {
+            Self::InternStr(symbol) => Some(StringValue::from(*symbol)),
+            Self::InlineStr(inline) => Some(StringValue::from(*inline)),
+            Self::GCStr(gc_str) => Some(StringValue::from(*gc_str)),
+            _ => None,
+        }
     }
     
     pub fn echo(&self) -> impl fmt::Display + '_ {
@@ -58,18 +69,24 @@ impl From<FloatType> for Variant {
 }
 
 impl From<StringValue> for Variant {
-    fn from(value: StringValue) -> Self { Self::String(value) }
+    fn from(value: StringValue) -> Self {
+        match value {
+            StringValue::Intern(symbol) => Self::InternStr(symbol),
+            StringValue::Inline(inline) => Self::InlineStr(inline),
+            StringValue::Gc(gc_str) => Self::GCStr(gc_str),
+        }
+    }
 }
 
 impl From<StringSymbol> for Variant {
     fn from(symbol: StringSymbol) -> Self {
-        Self::String(symbol.into())
+        Self::InternStr(symbol)
     }
 }
 
 impl From<&str> for Variant {
     fn from(string: &str) -> Self {
-        Self::String(string.into())
+        StringValue::from(string).into()
     }
 }
 
@@ -81,17 +98,17 @@ impl From<Box<[Variant]>> for Variant {
 
 impl From<Function> for Variant {
     fn from(func: Function) -> Self {
-        Self::Function(GC::new(func))
+        Self::Function(Gc::new(func))
     }
 }
 
 impl From<NativeFunction> for Variant {
     fn from(func: NativeFunction) -> Self {
-        Self::NativeFunction(GC::new(func))
+        Self::NativeFunction(Gc::new(func))
     }
 }
 
-unsafe impl GCTrace for Variant {
+unsafe impl GcTrace for Variant {
     #[inline]
     fn trace(&self) {
         match self {
@@ -104,21 +121,6 @@ unsafe impl GCTrace for Variant {
 }
 
 
-// extract the GC handle for GC'd types
-impl TryFrom<&Variant> for GC<dyn GCTrace> {
-    type Error = ();
-    
-    fn try_from(value: &Variant) -> Result<Self, Self::Error> {
-        match value {
-            Variant::Tuple(tuple) => tuple.as_gc().ok_or(()),
-            Variant::Function(fun) => Ok((*fun).into()),
-            Variant::NativeFunction(fun) => Ok((*fun).into()),
-            _ => Err(()),
-        }
-    }
-}
-
-
 // Not all Variants are hashable
 impl Variant {
     pub fn can_hash(&self) -> bool {
@@ -131,14 +133,14 @@ impl Variant {
     }
     
     fn try_hash<H: Hasher>(&self, state: &mut H) -> ExecResult<()> {
-        let discr = std::mem::discriminant(self);
+        let discr = core::mem::discriminant(self);
         
         match self {
             Self::Nil | Self::BoolTrue | Self::BoolFalse 
                 => discr.hash(state),
             
             Self::Integer(value) => (discr, value).hash(state),
-            Self::String(value) => (discr, value).hash(state),
+            
             Self::Function(fun) => (discr, fun).hash(state),
             Self::NativeFunction(fun) => (discr, fun).hash(state),
             Self::Tuple(items) => {
@@ -148,6 +150,9 @@ impl Variant {
                 }
             },
             
+            Self::InternStr(..) | Self::InlineStr(..) | Self::GCStr(..) =>
+                self.as_strval().unwrap().hash(state),
+            
             _ => return Err(ErrorKind::UnhashableValue(*self).into()),
         }
         Ok(())
@@ -178,46 +183,29 @@ impl Hash for VariantKey<'_> {
 
 impl<'s> PartialEq for VariantKey<'_> {
     fn eq(&self, other: &VariantKey) -> bool {
-        match (self.0, other.0) {
-            (Variant::Nil, Variant::Nil) => true,
-            (Variant::BoolTrue, Variant::BoolTrue) => true,
-            (Variant::BoolFalse, Variant::BoolFalse) => true,
-            
-            (Variant::Integer(a), Variant::Integer(b)) => a == b,
-            (Variant::String(a), Variant::String(b)) => a == b,
-            
-            (Variant::Tuple(a), Variant::Tuple(b)) if a.is_empty() && b.is_empty() => true,
-            (Variant::Tuple(a), Variant::Tuple(b)) => {
-                a.len() == b.len() && (
-                    a.as_ref().iter().zip(b.as_ref().iter())
-                        .all(|(a, b)| VariantKey(a) == VariantKey(b))
-                )
-            },
-            
-            (Variant::Function(a), Variant::Function(b)) => GC::ptr_eq(a, b),
-            (Variant::NativeFunction(a), Variant::NativeFunction(b)) => GC::ptr_eq(a, b),
-            
-            _ => false,
-        }
+        self.0.cmp_eq(other.0).unwrap_or(false)
     }
 }
 impl Eq for VariantKey<'_> { }
 
 impl fmt::Display for Variant {
-    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, fmt: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        if let Some(strval) = self.as_strval() {
+            return write!(fmt, "{}", strval)
+        }
+        
         match self {
             Self::Nil => fmt.write_str("nil"),
             Self::BoolTrue => fmt.write_str("true"),
             Self::BoolFalse => fmt.write_str("false"),
             
-            Self::String(value) => write!(fmt, "{}", value),
+            Self::InternStr(..) | Self::InlineStr(..) | Self::GCStr(..) => unreachable!(),
+            
             Self::Tuple(tuple) => write!(fmt, "{}", tuple),
             
             Self::Integer(value) => write!(fmt, "{}", *value),
             Self::Float(value) => {
-                if !value.is_finite() {
-                    write!(fmt, "{}", *value)
-                } else if value.trunc() != *value {
+                if !value.is_finite() || value.trunc() != *value {
                     write!(fmt, "{}", *value)
                 } else {
                     write!(fmt, "{}.0", value)
@@ -227,14 +215,21 @@ impl fmt::Display for Variant {
             Self::Function(fun) => write!(
                 fmt, "<{} at {:#X}>",
                 fun.signature().display_short(), 
-                GC::as_id(fun),
+                Gc::as_id(fun),
             ),
             
             Self::NativeFunction(fun) => write!(
                 fmt, "<built-in {} at {:#X}>",
                 fun.signature().display_short(),
-                GC::as_id(fun),
+                Gc::as_id(fun),
             ),
+            
+            Self::UserData(data) =>
+                if let Ok(name) = data.type_name() {
+                    write!(fmt, "<{} at {:#X}>", name, Gc::as_id(data))
+                } else {
+                    write!(fmt, "<userdata at {:#X}>", Gc::as_id(data))
+                }
         }
     }
 }
@@ -244,10 +239,10 @@ impl fmt::Display for Variant {
 struct EchoDisplay<'a>(&'a Variant);
 
 impl fmt::Display for EchoDisplay<'_> {
-    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match self.0 {
-            Variant::String(value) => write!(fmt, "\"{}\"", value),
-            _ => write!(fmt, "{}", self.0),
+    fn fmt(&self, fmt: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        if let Some(strval) = self.0.as_strval() {
+            return write!(fmt, "\"{}\"", strval)
         }
+        write!(fmt, "{}", self.0)
     }
 }
\ No newline at end of file
