@@ -1,8 +1,8 @@
-use std::cell::Cell;
-use std::ops::Deref;
+use core::cell::Cell;
+use core::ops::Deref;
 use crate::codegen::LocalIndex;
 use crate::runtime::{Variant, HashMap};
-use crate::runtime::gc::{GC, GCTrace, gc_collect};
+use crate::runtime::gc::{Gc, GcTrace, gc_collect};
 use crate::runtime::function::{Call, Function, Upvalue, UpvalueIndex, Closure};
 use crate::runtime::module::Module;
 use crate::runtime::errors::ExecResult;
@@ -27,14 +27,13 @@ enum Control {
     Continue,
     Call(CallInfo),
     Return,
-    Exit,
 }
 
 
 #[derive(Debug, Clone, Copy)]
 struct UpvalueRef {
     // TODO weak reference
-    fun: GC<Function>,
+    fun: Gc<Function>,
     index: UpvalueIndex,
 }
 
@@ -47,7 +46,7 @@ impl Deref for UpvalueRef {
     }
 }
 
-impl GC<Function> {
+impl Gc<Function> {
     #[inline(always)]
     fn ref_upvalue(self, index: UpvalueIndex) -> UpvalueRef {
         UpvalueRef {
@@ -73,7 +72,7 @@ pub struct VirtualMachine<'c> {
 
 impl<'c> VirtualMachine<'c> {
     /// Create a new VM with the specified root module and an empty main chunk
-    pub fn new(main_module: GC<Module>, main_chunk: &'c [u8]) -> Self {
+    pub fn new(main_module: Gc<Module>, main_chunk: &'c [u8]) -> Self {
         Self {
             traceback: Vec::new(),
             calls: Vec::new(),
@@ -98,7 +97,6 @@ impl<'c> VirtualMachine<'c> {
             .map_err(|error| error.extend_trace(self.traceback.iter().rev().cloned()))?;
         
         match control {
-            Control::Exit => return Ok(true),
             Control::Return if self.calls.is_empty() => return Ok(true),
             
             Control::Call(info) => self.setup_call(info)?,
@@ -128,7 +126,7 @@ impl<'c> VirtualMachine<'c> {
                     .expect("local index overflow");
                 
                 let mut frame = VMCallFrame::call_frame(module, chunk_id, call.frame, locals);
-                std::mem::swap(&mut self.frame, &mut frame);
+                core::mem::swap(&mut self.frame, &mut frame);
                 self.calls.push(frame);
                 
                 log::debug!("Setup call: {{ frame: {}, locals: {} }}", self.frame.start_index(), self.frame.locals());
@@ -143,7 +141,7 @@ impl<'c> VirtualMachine<'c> {
         let frame_idx = self.frame.start_index();
         
         let mut frame = self.calls.pop().expect("empty call stack");
-        std::mem::swap(&mut self.frame, &mut frame);
+        core::mem::swap(&mut self.frame, &mut frame);
         
         let retval = self.values.pop();
         self.values.truncate(frame_idx);
@@ -155,8 +153,8 @@ impl<'c> VirtualMachine<'c> {
     }
 }
 
-// trace through all GC roots
-unsafe impl GCTrace for VirtualMachine<'_> {
+// trace through all Gc roots
+unsafe impl GcTrace for VirtualMachine<'_> {
     fn trace(&self) {
         // trace through the value stack
         for value in self.values.stack.iter() {
@@ -198,7 +196,7 @@ impl ValueStack {
     }
     
     // Note: when moving values off the stack, make sure to copy *before* popping
-    // This ensures that the GC sees the values as rooted
+    // This ensures that the Gc sees the values as rooted
     
     #[inline(always)]
     fn len(&self) -> usize {
@@ -233,7 +231,7 @@ impl ValueStack {
     #[inline(always)]
     fn discard_at(&mut self, index: usize, count: usize) {
         let discard_range = index..(index + count);
-        self.stack.splice(discard_range, std::iter::empty());
+        self.stack.splice(discard_range, core::iter::empty());
     }
     
     #[inline(always)]
@@ -254,7 +252,7 @@ impl ValueStack {
     #[inline(always)]
     fn replace_many(&mut self, count: usize, value: Variant) {
         let replace_range = (self.stack.len()-count).. ;
-        self.stack.splice(replace_range, std::iter::once(value));
+        self.stack.splice(replace_range, core::iter::once(value));
     }
     
     #[inline(always)]
@@ -322,7 +320,7 @@ impl OpenUpvalues {
         self.upvalues.values().flat_map(|refs| refs.iter())
     }
     
-    fn register(&mut self, function: GC<Function>) {
+    fn register(&mut self, function: Gc<Function>) {
         for (index, upval) in function.upvalues().iter().enumerate() {
             if upval.closure().is_open() {
                 let upval_ref = function.ref_upvalue(index.try_into().unwrap());
@@ -346,7 +344,7 @@ impl OpenUpvalues {
     
     fn close_upvalues(&mut self, index: usize, value: Variant) {
         if let Some(upvalues) = self.upvalues.remove(&index) {
-            let gc_cell = GC::new(Cell::new(value));
+            let gc_cell = Gc::new(Cell::new(value));
             for upvalue in upvalues.iter() {
                 upvalue.close(gc_cell)
             }
