@@ -1,10 +1,9 @@
-use crate::language::{IntType, FloatType};
+use crate::language::IntType;
 use crate::codegen::{OpCode, LocalIndex, UpvalueTarget};
 use crate::debug::traceback::TraceSite;
 use crate::debug::snapshot::VMFrameSnapshot;
 use crate::runtime::Variant;
-use crate::runtime::gc::{GC, GCTrace};
-use crate::runtime::ops;
+use crate::runtime::gc::{Gc, GcTrace};
 use crate::runtime::function::{Function, Upvalue, UpvalueIndex};
 use crate::runtime::strings::StringSymbol;
 use crate::runtime::module::{Module, Access, Chunk, ConstID, FunctionID, FunctionProto};
@@ -44,10 +43,9 @@ use crate::runtime::vm::{ValueStack, OpenUpvalues, UpvalueRef, CallInfo, Control
 
 #[inline]
 fn into_name(value: Variant) -> StringSymbol {
-    match value {
-        Variant::String(strval) => strval.as_intern(),
-        _ => panic!("invalid operand"),
-    }
+    value.as_strval()
+        .expect("invalid operand")
+        .as_intern()
 }
 
 #[inline]
@@ -61,7 +59,7 @@ fn into_usize(value: Variant) -> usize {
 }
 
 #[inline]
-fn into_function(value: Variant) -> GC<Function> {
+fn into_function(value: Variant) -> Gc<Function> {
     match value {
         Variant::Function(fun) => fun,
         _ => panic!("invalid operand")
@@ -120,7 +118,7 @@ macro_rules! cond_jump {
 
 #[derive(Debug)]
 pub struct VMCallFrame<'c> {
-    module: GC<Module>,
+    module: Gc<Module>,
     chunk: &'c [u8],
     chunk_id: Chunk,
     frame_idx: usize,   // start index for this frame in the value stack
@@ -128,14 +126,14 @@ pub struct VMCallFrame<'c> {
     pc: usize,
 }
 
-unsafe impl GCTrace for VMCallFrame<'_> {
+unsafe impl GcTrace for VMCallFrame<'_> {
     fn trace(&self) {
         self.module.mark_trace();
     }
 }
 
 impl<'c> VMCallFrame<'c> {
-    pub fn call_frame(module: GC<Module>, fun_id: FunctionID, frame_idx: usize, locals: LocalIndex) -> Self {
+    pub fn call_frame(module: Gc<Module>, fun_id: FunctionID, frame_idx: usize, locals: LocalIndex) -> Self {
         
         // This hack allows us to get around the self-referentiality of storing both "module" and "chunk"
         // in the same struct. The alternative would be to store "chunk" as an `Option<Box<[u8]>>` and call 
@@ -155,7 +153,7 @@ impl<'c> VMCallFrame<'c> {
         }
     }
     
-    pub fn main_chunk(module: GC<Module>, chunk: &'c [u8]) -> Self {
+    pub fn main_chunk(module: Gc<Module>, chunk: &'c [u8]) -> Self {
         Self {
             module,
             chunk,
@@ -183,7 +181,7 @@ impl<'c> VMCallFrame<'c> {
 
     // convert a local variable index to an index into the value stack
     #[inline]
-    fn from_local_index(&self, local: LocalIndex) -> usize {
+    fn index_from_local(&self, local: LocalIndex) -> usize {
         self.frame_idx + usize::from(local)
     }
     
@@ -214,13 +212,13 @@ impl<'c> VMCallFrame<'c> {
     
     #[inline]
     fn get_upvalue(&self, stack: &ValueStack, index: UpvalueIndex) -> UpvalueRef {
-        let fun = into_function(*stack.peek_at(self.from_local_index(0)));
+        let fun = into_function(*stack.peek_at(self.index_from_local(0)));
         fun.ref_upvalue(index)
     }
     
     fn make_function(&self, stack: &ValueStack, proto: &FunctionProto) -> Function {
         let upvalues = proto.upvalues().iter().map(|upval| match upval {
-                UpvalueTarget::Local(index) => Upvalue::new(self.from_local_index(*index)),
+                UpvalueTarget::Local(index) => Upvalue::new(self.index_from_local(*index)),
                 UpvalueTarget::Upvalue(index) => (*self.get_upvalue(stack, *index)).clone(),
             })
             .collect::<Vec<Upvalue>>()
@@ -274,14 +272,14 @@ impl<'c> VMCallFrame<'c> {
             OpCode::LoadFunction => {
                 let fun_id = FunctionID::from(data[0]);
                 let proto = self.module.get_function(fun_id);
-                let function = GC::new(self.make_function(stack, proto));
+                let function = Gc::new(self.make_function(stack, proto));
                 upvalues.register(function);
                 stack.push(Variant::Function(function));
             }
             OpCode::LoadFunction16 => {
                 let fun_id = FunctionID::from(read_le_bytes!(u16, data));
                 let proto = self.module.get_function(fun_id);
-                let function = GC::new(self.make_function(stack, proto));
+                let function = Gc::new(self.make_function(stack, proto));
                 upvalues.register(function);
                 stack.push(Variant::Function(function));
             }
@@ -311,8 +309,9 @@ impl<'c> VMCallFrame<'c> {
                 let name = into_name(stack.pop());
                 let value = *stack.peek();
                 
-                let mut globals = self.module.globals().borrow_mut();
-                let store = globals.lookup_mut(&name)?;
+                let globals = self.module.globals();
+                let mut namespace = globals.borrow_mut();
+                let store = namespace.lookup_mut(&name)?;
                 *store = value;
             },
             OpCode::LoadGlobal => {
@@ -325,29 +324,29 @@ impl<'c> VMCallFrame<'c> {
             
             OpCode::InsertLocal => {
                 let value = *stack.peek();
-                stack.insert(self.from_local_index(self.locals), value);
+                stack.insert(self.index_from_local(self.locals), value);
                 self.locals += 1;
             },
             OpCode::StoreLocal => {
                 let index = LocalIndex::from(data[0]);
-                stack.replace_at(self.from_local_index(index), *stack.peek());
+                stack.replace_at(self.index_from_local(index), *stack.peek());
             },
             OpCode::StoreLocal16 => {
                 let index = LocalIndex::from(read_le_bytes!(u16, data));
-                stack.replace_at(self.from_local_index(index), *stack.peek());
+                stack.replace_at(self.index_from_local(index), *stack.peek());
             },
             OpCode::LoadLocal => {
                 let index = LocalIndex::from(data[0]);
-                stack.push(*stack.peek_at(self.from_local_index(index)));
+                stack.push(*stack.peek_at(self.index_from_local(index)));
             },
             OpCode::LoadLocal16 => {
                 let index = LocalIndex::from(read_le_bytes!(u16, data));
-                stack.push(*stack.peek_at(self.from_local_index(index)));
+                stack.push(*stack.peek_at(self.index_from_local(index)));
             },
             OpCode::DropLocals => {
                 let count = LocalIndex::from(data[0]);
                 
-                let locals_end_index = self.from_local_index(self.locals);
+                let locals_end_index = self.index_from_local(self.locals);
                 if stack.len() == locals_end_index {
                     stack.discard(usize::from(count));
                 } else {
@@ -380,12 +379,12 @@ impl<'c> VMCallFrame<'c> {
             
             OpCode::CloseUpvalue => {
                 let local_index = LocalIndex::from(data[0]);
-                let index = self.from_local_index(local_index);
+                let index = self.index_from_local(local_index);
                 upvalues.close_upvalues(index, *stack.peek_at(index));
             }
             OpCode::CloseUpvalue16 => {
                 let local_index = LocalIndex::from(read_le_bytes!(u16, data));
-                let index = self.from_local_index(local_index);
+                let index = self.index_from_local(local_index);
                 upvalues.close_upvalues(index, *stack.peek_at(index));
             }
             
